
#line 3 "lex.ncg.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer ncg_create_buffer
#define yy_delete_buffer ncg_delete_buffer
#define yy_flex_debug ncg_flex_debug
#define yy_init_buffer ncg_init_buffer
#define yy_flush_buffer ncg_flush_buffer
#define yy_load_buffer_state ncg_load_buffer_state
#define yy_switch_to_buffer ncg_switch_to_buffer
#define yyin ncgin
#define yyleng ncgleng
#define yylex ncglex
#define yylineno ncglineno
#define yyout ncgout
#define yyrestart ncgrestart
#define yytext ncgtext
#define yywrap ncgwrap
#define yyalloc ncgalloc
#define yyrealloc ncgrealloc
#define yyfree ncgfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE ncgrestart(ncgin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int ncgleng;

extern FILE *ncgin, *ncgout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up ncgtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up ncgtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via ncgrestart()), so that the user can continue scanning by
	 * just pointing ncgin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when ncgtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int ncgleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow ncgwrap()'s to do buffer switches
 * instead of setting up a fresh ncgin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void ncgrestart (FILE *input_file  );
void ncg_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE ncg_create_buffer (FILE *file,int size  );
void ncg_delete_buffer (YY_BUFFER_STATE b  );
void ncg_flush_buffer (YY_BUFFER_STATE b  );
void ncgpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void ncgpop_buffer_state (void );

static void ncgensure_buffer_stack (void );
static void ncg_load_buffer_state (void );
static void ncg_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER ncg_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE ncg_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE ncg_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE ncg_scan_bytes (yyconst char *bytes,int len  );

void *ncgalloc (yy_size_t  );
void *ncgrealloc (void *,yy_size_t  );
void ncgfree (void *  );

#define yy_new_buffer ncg_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        ncgensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ncg_create_buffer(ncgin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        ncgensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ncg_create_buffer(ncgin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *ncgin = (FILE *) 0, *ncgout = (FILE *) 0;

typedef int yy_state_type;

extern int ncglineno;

int ncglineno = 1;

extern char *ncgtext;
#define yytext_ptr ncgtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up ncgtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	ncgleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 30
#define YY_END_OF_BUFFER 31
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[236] =
    {   0,
        0,    0,   31,   29,   28,   17,   29,   29,   29,   29,
       19,   29,   22,   22,   16,   16,   16,   16,   16,   16,
       16,   16,   29,   16,   16,   16,   16,   16,   16,   16,
       16,   16,   16,   16,   29,   29,   29,   28,    0,    2,
        0,    0,    0,   19,   22,   22,    0,    0,   19,   19,
        0,   20,    1,   23,   23,   18,   23,   22,   21,    0,
       22,   18,   16,    0,    0,    0,    0,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   16,   16,   16,
       16,   16,    0,    0,   24,    0,    0,    0,    0,    0,

       19,    0,    0,   19,    1,   23,   19,   23,    0,    0,
       16,   16,   16,   16,   16,   16,   16,   16,   14,   16,
       16,   16,   16,   16,   16,   16,   16,    7,   16,   16,
       16,   16,   16,   16,    0,   27,   25,    0,    0,   19,
        0,   19,   20,   19,    0,   16,   16,   16,   16,   15,
       16,   16,   16,   16,    5,    4,   16,   16,   16,   16,
       16,    7,   16,   16,    3,   16,   16,   16,   25,    0,
       26,    0,   15,    0,   12,   16,   16,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   16,    6,   16,   16,
        0,   16,   16,   16,   16,   16,   16,   16,   16,    8,

       16,   16,   16,    0,   16,   16,   16,   16,    0,   16,
       16,   16,   16,   16,    0,   16,   16,   13,   13,   16,
       16,   16,   16,   16,   14,   16,    9,   16,   16,   16,
       16,   11,   16,   10,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    6,    6,    6,    6,    8,    6,
        6,    6,    9,    6,   10,   11,   12,   13,   14,   14,
       14,   14,   14,   14,   14,   15,   15,   16,    6,    6,
        6,    6,    6,   17,   18,   19,   20,   21,   22,   23,
       24,   24,   25,   24,   24,   26,   27,   28,   29,   24,
       24,   30,   31,   32,   33,   34,   24,   35,   24,   24,
        6,   36,    6,    6,   24,    6,   37,   38,   39,   40,

       41,   42,   43,   44,   45,   24,   24,   46,   47,   48,
       49,   24,   24,   50,   51,   52,   53,   54,   24,   35,
       55,   24,   56,    6,    6,    6,    1,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   58,   58,   58,   58,   58,   58,   58,   58,   58,

       58,   58,   58,   58,   58,   58,   58,   58,   58,   58,
       58,   58,   58,   58,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   60,
       60,   60,   60,   60,   60,   60,   60,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[61] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    3,    4,    4,
        4,    1,    5,    5,    5,    1,    4,    5,    5,    5,
        5,    5,    5,    4,    4,    6,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    5,    5,    5,    5,
        5,    5,    4,    4,    4,    6,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    7,    1,    4,    4,    4
    } ;

static yyconst flex_int16_t yy_base[246] =
    {   0,
        0,    0,  327, 1206,   59, 1206,   55,  277,   54,   59,
       88,  295,  124,  165,   30,   57,  159,   61,  141,  149,
      154,  174,   64,  166,  179,  191,  184,  199,  205,  212,
      219,  225,  232,  237,  244,  243,  237,   81,   87, 1206,
      278,  259,   91,    0,  118,    0,  139,  204,    0, 1206,
      289, 1206,    0,  240,   66,   72,  296, 1206, 1206,    0,
        0, 1206,  257,  313,  189,  188,  174,  276,  287,  295,
      324,  372,  292,  320,  308,  345,  363,  366,  375,  384,
      379,  393,  410,  405,  413,  423,  418,  438,  443,  450,
      458,  455,  172,  165, 1206,  197,  143,  196,  114,  274,

      506,  156,  311,  521,    0, 1206,  528,  346,  140,  126,
      521,  528,  517,  464,  524,  535,  554,  542,  549,  567,
      579,  570,  574,  561,  582,  607,  599,  610,  613,  624,
      616,  628,  644,  649,  124, 1206, 1206,  180,  159, 1206,
       54,  230,  236, 1206,  101,  661,  664,  655,  595,  669,
      682,  674,  689,  699,  695,  702,  710,  715,  720,  729,
      740,  735,  746,  750,  755,  760,  775,  765, 1206,  133,
     1206,  128, 1206,   65, 1206,  785,  790,  802,  794,  805,
      811,  821,  815,  831,  841,  860,  850,  857,  866,  869,
       63,  878,  887,  894,  897,  929,  903,  914,  922,  932,

      935,  947,  950,   35,  968,  964,  975,  943,  120,  993,
      996,  989, 1000, 1003,   25, 1009, 1028,    0,  122, 1021,
     1035, 1041, 1038, 1054, 1206, 1071, 1067, 1075, 1081, 1088,
     1092, 1206, 1100, 1206, 1206, 1160, 1167, 1171, 1177, 1184,
     1187,   66, 1191, 1194, 1199
    } ;

static yyconst flex_int16_t yy_def[246] =
    {   0,
      235,    1,  235,  235,  235,  235,  236,  237,  235,  235,
      235,  235,  235,  235,  238,  238,  238,  238,  238,  238,
      238,  238,  235,  238,  238,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  235,  235,  235,  235,  236,  235,
      236,  235,  239,   11,   14,   14,  235,  235,   11,  235,
      235,  235,  240,   13,  241,  241,  241,  235,  235,  242,
       14,  235,  238,  235,  235,  235,  235,  238,  238,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
      238,  238,  235,  235,  235,  235,  235,  243,   45,  235,

      235,  235,  235,  235,  240,  235,   57,  242,  235,  235,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  235,  235,  235,  235,  244,  235,
      235,  241,  241,  235,  235,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  235,  235,
      235,  235,  235,  235,  235,  238,  238,  238,  238,  238,
      238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
      235,  238,  238,  238,  238,  238,  238,  238,  238,  238,

      238,  238,  238,  235,  238,  238,  238,  238,  245,  238,
      238,  238,  238,  238,  235,  238,  238,  245,  245,  238,
      238,  238,  238,  238,  235,  238,  238,  238,  238,  238,
      238,  235,  238,  235,    0,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235
    } ;

static yyconst flex_int16_t yy_nxt[1267] =
    {   0,
        4,    5,    6,    5,    5,    4,    7,    8,    9,   10,
       11,   12,   13,   14,   14,    4,    4,   15,   15,   15,
       16,   17,   18,   15,   19,   15,   15,   20,   15,   15,
       15,   15,   21,   22,   15,   23,   15,   24,   25,   26,
       17,   27,   15,   15,   28,   29,   15,   30,   15,   31,
       32,   15,   33,   34,   15,    4,    4,   35,   36,   37,
       38,   40,   38,   38,   44,   64,   45,   46,   46,   44,
      108,   45,   46,   46,   68,   47,   79,   79,   79,  225,
       47,   69,   38,   48,   38,   38,  215,   65,   66,   67,
       41,  106,   64,   40,   47,  173,   64,  106,  174,   47,

       49,   49,   49,   97,   97,   70,   73,  204,   50,   51,
       52,  106,  191,   50,   65,   66,   67,  106,   65,   66,
       67,  219,   41,  219,  219,   98,  219,   50,   51,   52,
       99,   99,   99,   50,   44,  171,   54,   54,   54,  235,
      169,   55,   56,   55,   55,   57,   55,  100,  100,   58,
      137,  101,  101,  101,   59,  138,  138,   63,   60,  235,
       55,   56,   55,   55,   57,   55,  171,   71,   71,   58,
       75,   72,   72,   72,   59,   44,   64,   61,   61,   61,
       79,   77,  145,   62,   64,   76,   47,  169,   74,   64,
       58,   78,  170,  170,   64,   59,   63,  141,   65,   66,

       67,   64,   62,  136,  136,   47,   65,   66,   67,   64,
       58,   65,   66,   67,   64,   59,   65,   66,   67,   64,
       80,  135,   81,   65,   66,   67,   64,   82,   79,   85,
      110,   65,   66,   67,   64,   83,   65,   66,   67,   84,
       64,   65,   66,   67,  109,   63,   86,   64,   65,   66,
       67,  102,   88,   87,   64,  106,   65,   66,   67,   89,
       64,  106,   65,   66,   67,  106,   95,   64,   90,   65,
       66,   67,   64,   92,  235,  106,   65,   66,   67,   91,
      235,  106,   65,   66,   67,  106,  101,  101,  101,   65,
       66,   67,   64,   94,   65,   66,   67,  103,  103,   93,

       79,  104,  104,  104,  100,  100,   53,  111,  107,  107,
      107,   64,   43,  112,   65,   66,   67,   63,   63,   63,
       63,  106,   64,  104,  104,  104,  235,   64,   63,  235,
       64,  235,  235,   65,   66,   67,   72,   72,   72,  118,
      116,  106,  235,   64,   65,   66,   67,  113,   63,   65,
       66,   67,   65,   66,   67,   64,  235,  235,  235,   64,
      235,  117,  235,  235,  235,   65,   66,   67,   63,  235,
      235,  106,  119,  235,  235,  235,   59,   65,   66,   67,
       64,   65,   66,   67,   72,   72,   72,  235,  120,  235,
      235,  106,  114,  235,  115,  121,   59,  114,   64,  235,

      235,   64,   65,   66,   67,  235,  235,   64,  235,  235,
       64,  114,  235,  115,   64,  123,  235,  114,  235,   64,
       65,   66,   67,   65,   66,   67,  235,  235,   64,   65,
       66,   67,   65,   66,   67,  122,   65,   66,   67,  235,
       64,   65,   66,   67,  124,   64,  235,  235,   64,  235,
       65,   66,   67,   64,  235,  235,  125,  126,   64,  235,
      235,  127,   65,   66,   67,  129,  235,   65,   66,   67,
       65,   66,   67,   64,  128,   65,   66,   67,   64,  131,
       65,   66,   67,  235,  235,   64,  235,  235,  235,  130,
       64,  235,  235,   64,  235,   65,   66,   67,  132,   64,

       65,   66,   67,  133,  134,  235,  235,   65,   66,   67,
      235,  235,   65,   66,   67,   65,   66,   67,  101,  101,
      101,   65,   66,   67,  235,  235,  140,  235,   52,  235,
      235,  140,  235,  104,  104,  104,  235,  235,  146,  235,
      235,   50,  235,   52,  235,  140,   50,   52,  142,  147,
      143,  140,   64,  144,  148,  235,   64,  235,  235,   64,
       50,  152,   52,   64,  235,  235,   50,  142,  235,  143,
       64,  149,  235,  144,   65,   66,   67,   64,   65,   66,
       67,   65,   66,   67,   64,   65,   66,   67,  235,   64,
      235,  153,   65,   66,   67,  150,   64,  157,  151,   65,

       66,   67,   64,  154,  235,   64,   65,   66,   67,   64,
      155,   65,   66,   67,   64,  235,  235,   64,   65,   66,
       67,  235,  158,  156,   65,   66,   67,   65,   66,   67,
       64,   65,   66,   67,   64,  160,   65,   66,   67,   65,
       66,   67,   64,  163,  159,   64,  178,  235,   64,  235,
      161,   64,   65,   66,   67,  162,   65,   66,   67,   64,
      235,  165,  164,   64,   65,   66,   67,   65,   66,   67,
       65,   66,   67,   65,   66,   67,  175,  166,  235,   64,
      235,   65,   66,   67,   64,   65,   66,   67,  167,  235,
       64,  176,  235,  168,  180,  235,   64,  235,  235,   64,

      177,   65,   66,   67,   64,  235,   65,   66,   67,   64,
      235,  235,   65,   66,   67,  181,  182,   64,   65,   66,
       67,   65,   66,   67,   64,  175,   65,   66,   67,  179,
       64,   65,   66,   67,   64,  235,  235,   64,  235,   65,
       66,   67,  235,  235,  235,   64,   65,   66,   67,  235,
       64,  235,   65,   66,   67,   64,   65,   66,   67,   65,
       66,   67,  183,  235,   64,  184,  186,   65,   66,   67,
       64,  235,   65,   66,   67,   64,  235,   65,   66,   67,
      165,   64,  185,  235,  235,   64,   65,   66,   67,  187,
       64,  235,   65,   66,   67,   64,  235,   65,   66,   67,

       64,  190,  235,   65,   66,   67,  235,   65,   66,   67,
       64,  188,   65,   66,   67,  192,  235,   65,   66,   67,
       64,  189,   65,   66,   67,   64,  194,  196,  235,   64,
      193,  235,   65,   66,   67,  197,  235,   64,  195,  198,
       64,  235,   65,   66,   67,  235,   64,   65,   66,   67,
       64,   65,   66,   67,  235,  235,   64,  235,  235,   65,
       66,   67,   65,   66,   67,  199,   64,  235,   65,   66,
       67,  200,   65,   66,   67,  235,   64,  235,   65,   66,
       67,  201,  196,  235,  235,   64,  235,  235,   65,   66,
       67,  196,   64,  235,  235,   64,  235,  235,   65,   66,

       67,   64,  205,  235,   64,  235,  203,   65,   66,   67,
      202,  206,  235,   64,   65,   66,   67,   65,   66,   67,
      235,  235,   64,   65,   66,   67,   65,   66,   67,   64,
      209,  235,   64,  209,  210,   65,   66,   67,   64,  211,
      235,  207,  235,  235,   65,   66,   67,  235,  208,   64,
      235,   65,   66,   67,   65,   66,   67,   64,  235,  235,
       65,   66,   67,  235,   64,  235,  212,   64,  235,  235,
       64,   65,   66,   67,  235,  235,  235,  235,   64,   65,
       66,   67,   64,  235,  162,   64,   65,   66,   67,   65,
       66,   67,   65,   66,   67,  214,  216,  119,  213,   64,

       65,   66,   67,   64,   65,   66,   67,   65,   66,   67,
       64,  217,  235,  235,  220,  235,  150,  221,  235,  235,
      235,   65,   66,   67,   64,   65,   66,   67,   64,  235,
      235,   64,   65,   66,   67,   64,  226,  222,   64,  235,
      223,  227,  235,  224,   64,  235,   65,   66,   67,  235,
       65,   66,   67,   65,   66,   67,   64,   65,   66,   67,
       65,   66,   67,   64,  235,  228,   65,   66,   67,  119,
       64,  235,  235,   64,  235,  235,   64,  227,   65,   66,
       67,  235,  235,  235,  235,   65,   66,   67,  229,   64,
      232,  235,   65,   66,   67,   65,   66,   67,   65,   66,

       67,  231,   64,  232,  230,  235,   64,  234,  235,  235,
       64,   65,   66,   67,  235,  234,   64,  235,  235,  235,
      235,  235,  235,   64,   65,   66,   67,   64,   65,   66,
       67,  233,   65,   66,   67,   64,  235,  235,   65,   66,
       67,  235,  235,  235,  235,   65,   66,   67,  235,   65,
       66,   67,  235,  235,  235,  235,  235,   65,   66,   67,
       39,   39,   39,   39,   39,   39,   39,   42,   42,   42,
       42,   42,   42,   42,   63,   63,   63,   96,  235,   96,
       96,   96,   96,   96,  105,  235,  105,  105,  105,  105,
      105,   55,   55,  139,  235,  139,  172,  235,  172,  218,

      218,  218,  218,  218,  218,    3,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235
    } ;

static yyconst flex_int16_t yy_chk[1267] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        5,    7,    5,    5,    9,   15,    9,    9,    9,   10,
      242,   10,   10,   10,   16,    9,   23,   23,   23,  215,
       10,   16,   38,   10,   38,   38,  204,   15,   15,   15,
        7,   55,   16,   39,    9,  141,   18,   56,  141,   10,

       11,   11,   11,   43,   43,   16,   18,  191,   11,   11,
       11,   55,  174,   11,   16,   16,   16,   56,   18,   18,
       18,  209,   39,  219,  209,   43,  219,   11,   11,   11,
       45,   45,   45,   11,   13,  172,   13,   13,   13,   99,
      170,   13,   13,   13,   13,   13,   13,   47,   47,   13,
       97,   47,   47,   47,   13,   97,   97,  145,   13,   99,
       13,   13,   13,   13,   13,   13,  139,   17,   17,   13,
       20,   17,   17,   17,   13,   14,   19,   14,   14,   14,
      135,   21,  110,   14,   20,   20,   14,  138,   19,   21,
       14,   22,  138,  138,   17,   14,  109,  102,   19,   19,

       19,   24,   14,   98,   96,   14,   20,   20,   20,   22,
       14,   21,   21,   21,   25,   14,   17,   17,   17,   27,
       24,   94,   25,   24,   24,   24,   26,   26,   93,   27,
       67,   22,   22,   22,   28,   26,   25,   25,   25,   26,
       29,   27,   27,   27,   66,   65,   28,   30,   26,   26,
       26,   48,   30,   29,   31,  142,   28,   28,   28,   31,
       32,  143,   29,   29,   29,   54,   42,   33,   32,   30,
       30,   30,   34,   34,   54,  142,   31,   31,   31,   33,
       41,  143,   32,   32,   32,   54,  100,  100,  100,   33,
       33,   33,   63,   37,   34,   34,   34,   51,   51,   36,

       35,   51,   51,   51,   57,   57,   12,   68,   57,   57,
       57,   68,    8,   69,   63,   63,   63,   64,   64,   64,
       64,   57,   69,  103,  103,  103,    3,   73,   64,    0,
       70,    0,    0,   68,   68,   68,   71,   71,   71,   75,
       73,   57,    0,   75,   69,   69,   69,   70,   64,   73,
       73,   73,   70,   70,   70,   74,    0,    0,    0,   71,
        0,   74,    0,    0,    0,   75,   75,   75,   64,    0,
        0,  108,   76,    0,    0,    0,  108,   74,   74,   74,
       76,   71,   71,   71,   72,   72,   72,    0,   77,    0,
        0,  108,   72,    0,   72,   78,  108,   72,   77,    0,

        0,   78,   76,   76,   76,    0,    0,   72,    0,    0,
       79,   72,    0,   72,   81,   81,    0,   72,    0,   80,
       77,   77,   77,   78,   78,   78,    0,    0,   82,   72,
       72,   72,   79,   79,   79,   80,   81,   81,   81,    0,
       84,   80,   80,   80,   82,   83,    0,    0,   85,    0,
       82,   82,   82,   87,    0,    0,   83,   84,   86,    0,
        0,   85,   84,   84,   84,   87,    0,   83,   83,   83,
       85,   85,   85,   88,   86,   87,   87,   87,   89,   89,
       86,   86,   86,    0,    0,   90,    0,    0,    0,   88,
       92,    0,    0,   91,    0,   88,   88,   88,   90,  114,

       89,   89,   89,   91,   92,    0,    0,   90,   90,   90,
        0,    0,   92,   92,   92,   91,   91,   91,  101,  101,
      101,  114,  114,  114,    0,    0,  101,    0,  101,    0,
        0,  101,    0,  104,  104,  104,  107,  107,  111,    0,
        0,  104,    0,  104,    0,  101,  104,  101,  107,  112,
      107,  101,  113,  107,  113,    0,  111,    0,    0,  115,
      104,  118,  104,  112,    0,    0,  104,  107,    0,  107,
      116,  116,    0,  107,  113,  113,  113,  118,  111,  111,
      111,  115,  115,  115,  119,  112,  112,  112,    0,  117,
        0,  120,  116,  116,  116,  117,  124,  124,  117,  118,

      118,  118,  120,  121,    0,  122,  119,  119,  119,  123,
      122,  117,  117,  117,  121,    0,    0,  125,  124,  124,
      124,    0,  125,  123,  120,  120,  120,  122,  122,  122,
      149,  123,  123,  123,  127,  127,  121,  121,  121,  125,
      125,  125,  126,  130,  126,  128,  149,    0,  129,    0,
      128,  131,  149,  149,  149,  129,  127,  127,  127,  130,
        0,  131,  130,  132,  126,  126,  126,  128,  128,  128,
      129,  129,  129,  131,  131,  131,  146,  132,    0,  133,
        0,  130,  130,  130,  134,  132,  132,  132,  133,    0,
      148,  147,    0,  134,  152,    0,  146,    0,    0,  147,

      148,  133,  133,  133,  150,    0,  134,  134,  134,  152,
        0,    0,  148,  148,  148,  153,  154,  151,  146,  146,
      146,  147,  147,  147,  153,  157,  150,  150,  150,  151,
      155,  152,  152,  152,  154,    0,    0,  156,    0,  151,
      151,  151,    0,    0,    0,  157,  153,  153,  153,    0,
      158,    0,  155,  155,  155,  159,  154,  154,  154,  156,
      156,  156,  158,    0,  160,  159,  163,  157,  157,  157,
      162,    0,  158,  158,  158,  161,    0,  159,  159,  159,
      160,  163,  161,    0,    0,  164,  160,  160,  160,  164,
      165,    0,  162,  162,  162,  166,    0,  161,  161,  161,

      168,  168,    0,  163,  163,  163,    0,  164,  164,  164,
      167,  166,  165,  165,  165,  176,    0,  166,  166,  166,
      176,  167,  168,  168,  168,  177,  178,  180,    0,  179,
      177,    0,  167,  167,  167,  181,    0,  178,  179,  182,
      180,    0,  176,  176,  176,    0,  181,  177,  177,  177,
      183,  179,  179,  179,    0,    0,  182,    0,    0,  178,
      178,  178,  180,  180,  180,  183,  184,    0,  181,  181,
      181,  184,  183,  183,  183,    0,  185,    0,  182,  182,
      182,  185,  186,    0,    0,  187,    0,    0,  184,  184,
      184,  187,  188,    0,    0,  186,    0,    0,  185,  185,

      185,  189,  192,    0,  190,    0,  190,  187,  187,  187,
      189,  193,    0,  192,  188,  188,  188,  186,  186,  186,
        0,    0,  193,  189,  189,  189,  190,  190,  190,  194,
      196,    0,  195,  196,  197,  192,  192,  192,  197,  198,
        0,  194,    0,    0,  193,  193,  193,    0,  195,  198,
        0,  194,  194,  194,  195,  195,  195,  199,    0,    0,
      197,  197,  197,    0,  196,    0,  199,  200,    0,    0,
      201,  198,  198,  198,    0,    0,    0,    0,  208,  199,
      199,  199,  202,    0,  201,  203,  196,  196,  196,  200,
      200,  200,  201,  201,  201,  203,  205,  208,  202,  206,

      208,  208,  208,  205,  202,  202,  202,  203,  203,  203,
      207,  206,    0,    0,  210,    0,  207,  211,    0,    0,
        0,  206,  206,  206,  212,  205,  205,  205,  210,    0,
        0,  211,  207,  207,  207,  213,  216,  212,  214,    0,
      213,  220,    0,  214,  216,    0,  212,  212,  212,    0,
      210,  210,  210,  211,  211,  211,  220,  213,  213,  213,
      214,  214,  214,  217,    0,  221,  216,  216,  216,  217,
      221,    0,    0,  223,    0,    0,  222,  223,  220,  220,
      220,    0,    0,    0,    0,  217,  217,  217,  222,  224,
      228,    0,  221,  221,  221,  223,  223,  223,  222,  222,

      222,  226,  227,  230,  224,    0,  226,  231,    0,    0,
      228,  224,  224,  224,    0,  233,  229,    0,    0,    0,
        0,    0,    0,  230,  227,  227,  227,  231,  226,  226,
      226,  229,  228,  228,  228,  233,    0,    0,  229,  229,
      229,    0,    0,    0,    0,  230,  230,  230,    0,  231,
      231,  231,    0,    0,    0,    0,    0,  233,  233,  233,
      236,  236,  236,  236,  236,  236,  236,  237,  237,  237,
      237,  237,  237,  237,  238,  238,  238,  239,    0,  239,
      239,  239,  239,  239,  240,    0,  240,  240,  240,  240,
      240,  241,  241,  243,    0,  243,  244,    0,  244,  245,

      245,  245,  245,  245,  245,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int ncg_flex_debug;
int ncg_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *ncgtext;
#line 1 "ncgen.l"
#line 2 "ncgen.l"
/*********************************************************************
 *   Copyright 1993, UCAR/Unidata
 *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
 *   $Id: ncgen.l,v 1.24 2009/12/29 18:42:36 dmh Exp $
 *********************************************************************/

/* Problems:
1. Ideally, we assume the input is true ut8.
   Unfortunately, we may actually get iso-latin-8859-1.
   This means that there will be ambiguity about the characters
   in the range 128-255 because they will look like n-byte unicode
   when they are 1-byte 8859 characters. Because of our encoding,
   8859 characters above 128 will be handles as n-byte utf8 and so
   will probably not lex correctly.
   Solution: assume utf8 and note in the documentation that
   ISO8859 is specifically unsupported.
2. The netcdf function NC_check_name in string.c must be modified to
   conform to the use of UTF8.
3. We actually have three tests for UTF8 of increasing correctness
   (in the sense that the least correct will allow some sequences that
    are technically illegal UTF8).
   The tests are derived from the table at
	    http://www.w3.org/2005/03/23-lex-U
   We include lexical definitions for all three, but use the second version.
*/

/* lex specification for tokens for ncgen */

/* Fill value used by ncdump from version 2.4 and later.  Should match
   definition of FILL_STRING in ../ncdump/vardata.h */
#define FILL_STRING "_"
#define XDR_INT_MIN (-2147483647-1)
#define XDR_INT_MAX 2147483647

char errstr[100];		/* for short error messages */

#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include "genlib.h"
#include "ncgentab.h"

#define YY_BREAK                /* defining as nothing eliminates unreachable
				   statement warnings from flex output, 
                                   but make sure every action ends with
                                   "return" or "break"! */

/* The most correct (validating) version of UTF8 character set
   (Taken from: http://www.w3.org/2005/03/23-lex-U)

The lines of the expression cover the UTF8 characters as follows:
1. non-overlong 2-byte
2. excluding overlongs
3. straight 3-byte
4. excluding surrogates
5. straight 3-byte
6. planes 1-3
7. planes 4-15
8. plane 16

UTF8   ([\xC2-\xDF][\x80-\xBF])                       \
     | (\xE0[\xA0-\xBF][\x80-\xBF])                   \
     | ([\xE1-\xEC][\x80-\xBF][\x80-\xBF])            \
     | (\xED[\x80-\x9F][\x80-\xBF])                   \
     | ([\xEE-\xEF][\x80-\xBF][\x80-\xBF])            \
     | (\xF0[\x90-\xBF][\x80-\xBF][\x80-\xBF])        \
     | ([\xF1-\xF3][\x80-\xBF][\x80-\xBF][\x80-\xBF]) \
     | (\xF4[\x80-\x8F][\x80-\xBF][\x80-\xBF])        \

*/
/* Wish there was some way to ifdef lex files */
/*The most relaxed version of UTF8 (not used)
UTF8 ([\xC0-\xD6].)|([\xE0-\xEF]..)|([\xF0-\xF7]...)
*/
/*The partially relaxed version of UTF8, and the one used here */
/* The old definition of ID
ID ([A-Za-z_]|{UTF8})([A-Z.@#\[\]a-z_0-9+-]|{UTF8})*
*/
/* Don't permit control characters or '/' in names, but other special
   chars OK if escaped.  Note that to preserve backwards
   compatibility, none of the characters _.@+- should be escaped, as
   they were previously permitted in names without escaping.  */
/* New definition to conform to a subset of string.c */
/* Note: this definition of string will work for utf8 as well,
   although it is a very relaxed definition
*/
#line 913 "lex.ncg.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int ncglex_destroy (void );

int ncgget_debug (void );

void ncgset_debug (int debug_flag  );

YY_EXTRA_TYPE ncgget_extra (void );

void ncgset_extra (YY_EXTRA_TYPE user_defined  );

FILE *ncgget_in (void );

void ncgset_in  (FILE * in_str  );

FILE *ncgget_out (void );

void ncgset_out  (FILE * out_str  );

int ncgget_leng (void );

char *ncgget_text (void );

int ncgget_lineno (void );

void ncgset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int ncgwrap (void );
#else
extern int ncgwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( ncgtext, ncgleng, 1, ncgout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		unsigned n; \
		for ( n = 0; n < max_size && \
			     (c = getc( ncgin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( ncgin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, ncgin))==0 && ferror(ncgin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(ncgin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int ncglex (void);

#define YY_DECL int ncglex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after ncgtext and ncgleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 107 "ncgen.l"

#line 1097 "lex.ncg.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! ncgin )
			ncgin = stdin;

		if ( ! ncgout )
			ncgout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			ncgensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				ncg_create_buffer(ncgin,YY_BUF_SIZE );
		}

		ncg_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of ncgtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 236 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1206 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 108 "ncgen.l"
{ /* comment */ 
                          break;
                        }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 112 "ncgen.l"
{
			 if(ncgleng > MAXTRST) {
				yyerror("string too long, truncated\n");
			        ncgtext[MAXTRST-1] = '\0';
			 }
			 expand_escapes(termstring,(char *)ncgtext,ncgleng);
		 	 return (TERMSTRING);
		        }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 121 "ncgen.l"
{return (FLOAT_K);}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 122 "ncgen.l"
{return (CHAR_K);}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 123 "ncgen.l"
{return (BYTE_K);}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 124 "ncgen.l"
{return (SHORT_K);}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 125 "ncgen.l"
{return (INT_K);}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 126 "ncgen.l"
{return (DOUBLE_K);}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 127 "ncgen.l"
{int_val = -1;
			 return (NC_UNLIMITED_K);}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 130 "ncgen.l"
{return (DIMENSIONS);}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 131 "ncgen.l"
{return (VARIABLES);}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 132 "ncgen.l"
{return (DATA);}
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 133 "ncgen.l"
{
		char *s = (char*)ncgtext+strlen("netcdf");
		char *t = (char*)ncgtext+ncgleng-1;
		while (isspace(*s))
			s++;
		while (isspace(*t))
			t--;
		t++;
                if (t-s+1 < 1) {
                        yyerror("netCDF name required");
                        return (DATA); /* generate syntax error */
                }
		netcdfname = (char *) emalloc(t-s+1);
		(void) strncpy(netcdfname, s, t-s);
		netcdfname[t-s] = '\0';
		deescapify(netcdfname);  /* so "\5foo" becomes "5foo", for example */
		return (NETCDF);
		}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 151 "ncgen.l"
{ /* missing value (pre-2.4 backward compatibility) */
                if (ncgtext[0] == '-') {
		    double_val = -NC_FILL_DOUBLE;
                } else {
		    double_val = NC_FILL_DOUBLE;
                }
		return (DOUBLE_CONST);
		}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 159 "ncgen.l"
{ /* missing value (pre-2.4 backward compatibility) */
                if (ncgtext[0] == '-') {
		    float_val = -NC_FILL_FLOAT;
                } else {
		    float_val = NC_FILL_FLOAT;
                }
		return (FLOAT_CONST);
		}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 167 "ncgen.l"
{
                if (STREQ((char *)ncgtext, FILL_STRING))
		        return (FILLVALUE);
		if ((yylval = lookup((char *)ncgtext)) == NULL) {
			yylval = install((char *)ncgtext);
			}
		return (IDENT);
		}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 176 "ncgen.l"
{
		lineno++ ;
                break;
		}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 181 "ncgen.l"
{
                int ii;
		if (sscanf((char*)ncgtext, "%d", &ii) != 1) {
		    sprintf(errstr,"bad byte constant: %s",(char*)ncgtext);
		    yyerror(errstr);
		}
                byte_val = ii;
		if (ii != (int)byte_val) {
		    sprintf(errstr,"byte constant out of range (-128,127): %s",(char*)ncgtext);
		    yyerror(errstr);
		}
		return (BYTE_CONST);
                }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 195 "ncgen.l"
{
		if (sscanf((char*)ncgtext, "%le", &double_val) != 1) {
		    sprintf(errstr,"bad long or double constant: %s",(char*)ncgtext);
		    yyerror(errstr);
		}
                return (DOUBLE_CONST);
                }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 202 "ncgen.l"
{
		if (sscanf((char*)ncgtext, "%e", &float_val) != 1) {
		    sprintf(errstr,"bad float constant: %s",(char*)ncgtext);
		    yyerror(errstr);
		}
                return (FLOAT_CONST);
                }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 209 "ncgen.l"
{
		if (sscanf((char*)ncgtext, "%hd", &short_val) != 1) {
		    sprintf(errstr,"bad short constant: %s",(char*)ncgtext);
		    yyerror(errstr);
		}
		return (SHORT_CONST);
	        }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 216 "ncgen.l"
{
    		char *ptr;
                errno = 0;
		double_val = strtod((char*)ncgtext, &ptr);
		if (errno != 0 && double_val == 0.0) {
		    sprintf(errstr,"bad numerical constant: %s",(char*)ncgtext);
		    yyerror(errstr);
		}
                if (double_val < XDR_INT_MIN ||double_val > XDR_INT_MAX) {
                    return DOUBLE_CONST;
                } else {
                    int_val = (int) double_val;
                    return INT_CONST;
                }
	        }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 231 "ncgen.l"
{
    		char *ptr;
                long long_val;
                errno = 0;
		long_val = strtol((char*)ncgtext, &ptr, 0);
		if (errno != 0) {
		    sprintf(errstr,"bad long constant: %s",(char*)ncgtext);
		    yyerror(errstr);
		}
                if (long_val < XDR_INT_MIN || long_val > XDR_INT_MAX) {
                    double_val = (double) long_val;
                    return DOUBLE_CONST;
                } else {
                    int_val = (int) long_val;
                    return INT_CONST;
                }
	        }
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 248 "ncgen.l"
{
	        (void) sscanf((char*)&ncgtext[1],"%c",&byte_val);
		return (BYTE_CONST);
                }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 252 "ncgen.l"
{
		byte_val = (char) strtol((char*)&ncgtext[2], (char **) 0, 8);
		return (BYTE_CONST);
                }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 256 "ncgen.l"
{
		byte_val = (char) strtol((char*)&ncgtext[3], (char **) 0, 16);
		return (BYTE_CONST);
                }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 260 "ncgen.l"
{
	       switch ((char)ncgtext[2]) {
	          case 'a': byte_val = '\007'; break; /* not everyone under-
						       * stands '\a' yet */
     	          case 'b': byte_val = '\b'; break;
		  case 'f': byte_val = '\f'; break;
		  case 'n': byte_val = '\n'; break;
		  case 'r': byte_val = '\r'; break;
		  case 't': byte_val = '\t'; break;
		  case 'v': byte_val = '\v'; break;
		  case '\\': byte_val = '\\'; break;
		  case '?': byte_val = '\177'; break;
		  case '\'': byte_val = '\''; break;
		  default: byte_val = (char)ncgtext[2];
	           }
		return (BYTE_CONST);
                }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 278 "ncgen.l"
{ /* whitespace */ 
		  break;        
		}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 281 "ncgen.l"
{/* Note: this next rule will not work for UTF8 characters */
		return (ncgtext[0]) ;
		}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 285 "ncgen.l"
ECHO;
	YY_BREAK
#line 1474 "lex.ncg.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed ncgin at a new source and called
			 * ncglex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = ncgin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( ncgwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * ncgtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of ncglex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					ncgrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			ncgrestart(ncgin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) ncgrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 236 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 236 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 235);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up ncgtext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					ncgrestart(ncgin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( ncgwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve ncgtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void ncgrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        ncgensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            ncg_create_buffer(ncgin,YY_BUF_SIZE );
	}

	ncg_init_buffer(YY_CURRENT_BUFFER,input_file );
	ncg_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void ncg_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		ncgpop_buffer_state();
	 *		ncgpush_buffer_state(new_buffer);
     */
	ncgensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	ncg_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (ncgwrap()) processing, but the only time this flag
	 * is looked at is after ncgwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void ncg_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	ncgin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE ncg_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) ncgalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ncg_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) ncgalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in ncg_create_buffer()" );

	b->yy_is_our_buffer = 1;

	ncg_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with ncg_create_buffer()
 * 
 */
    void ncg_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		ncgfree((void *) b->yy_ch_buf  );

	ncgfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a ncgrestart() or at EOF.
 */
    static void ncg_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	ncg_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then ncg_init_buffer was _probably_
     * called from ncgrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void ncg_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		ncg_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void ncgpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	ncgensure_buffer_stack();

	/* This block is copied from ncg_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from ncg_switch_to_buffer. */
	ncg_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void ncgpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	ncg_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		ncg_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void ncgensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)ncgalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in ncgensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)ncgrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in ncgensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE ncg_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) ncgalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ncg_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	ncg_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to ncglex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       ncg_scan_bytes() instead.
 */
YY_BUFFER_STATE ncg_scan_string (yyconst char * yystr )
{
    
	return ncg_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to ncglex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE ncg_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) ncgalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in ncg_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = ncg_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in ncg_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up ncgtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		ncgtext[ncgleng] = (yy_hold_char); \
		(yy_c_buf_p) = ncgtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		ncgleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int ncgget_lineno  (void)
{
        
    return ncglineno;
}

/** Get the input stream.
 * 
 */
FILE *ncgget_in  (void)
{
        return ncgin;
}

/** Get the output stream.
 * 
 */
FILE *ncgget_out  (void)
{
        return ncgout;
}

/** Get the length of the current token.
 * 
 */
int ncgget_leng  (void)
{
        return ncgleng;
}

/** Get the current token.
 * 
 */

char *ncgget_text  (void)
{
        return ncgtext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void ncgset_lineno (int  line_number )
{
    
    ncglineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see ncg_switch_to_buffer
 */
void ncgset_in (FILE *  in_str )
{
        ncgin = in_str ;
}

void ncgset_out (FILE *  out_str )
{
        ncgout = out_str ;
}

int ncgget_debug  (void)
{
        return ncg_flex_debug;
}

void ncgset_debug (int  bdebug )
{
        ncg_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from ncglex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    ncgin = stdin;
    ncgout = stdout;
#else
    ncgin = (FILE *) 0;
    ncgout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * ncglex_init()
     */
    return 0;
}

/* ncglex_destroy is for both reentrant and non-reentrant scanners. */
int ncglex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		ncg_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		ncgpop_buffer_state();
	}

	/* Destroy the stack itself. */
	ncgfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * ncglex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *ncgalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *ncgrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void ncgfree (void * ptr )
{
	free( (char *) ptr );	/* see ncgrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 285 "ncgen.l"



/* Hack to keep compile quiet */
void
ignore()
{
    yyunput(0,NULL);

}


